@@ -1,5 +1,5 @@
 # Copyright 2021-2023 Datum Technology Corporation
-# SPDX-License-Identifier: Apache-2.0 WITH SHL-2.1
+# SPDX-License-Identifier: Apache-2.0
 ########################################################################################################################
 
 
@@ -655,7 +655,7 @@ class Dependency:
         self.semver    = semver
         self.owner_ip  = owner_ip
         self.target_ip_model = None
-        common.dbg(f"Dependency after parsing: vendor='{self.vendor}' , target_ip='{self.target_ip}'")
+        #common.dbg(f"Dependency after parsing: vendor='{self.vendor}' , target_ip='{self.target_ip}'")
     
     def parse_dep_string(self, string):
         clean_str = string.lower().strip()
