@@ -1,5 +1,5 @@
 # Copyright 2021-2023 Datum Technology Corporation
-# SPDX-License-Identifier: Apache-2.0 WITH SHL-2.1
+# SPDX-License-Identifier: Apache-2.0
 ########################################################################################################################
 
 
@@ -301,7 +301,7 @@ class TestSuite:
         sim_job.is_regression   = True
         sim_job.regression_name = cfg.regression_name
         sim_job.regression_timestamp = self.timestamp
-        sim_job.one_shot  = True
+        sim_job.fsoc      = True
         sim_job.compile   = True
         sim_job.elaborate = True
         sim_job.simulate  = False
@@ -323,7 +323,7 @@ class TestSuite:
         sim_job.is_regression   = True
         sim_job.regression_name = cfg.regression_name
         sim_job.regression_timestamp = self.timestamp
-        sim_job.one_shot  = False
+        sim_job.fsoc      = True
         sim_job.compile   = True
         sim_job.elaborate = False
         sim_job.simulate  = False
@@ -584,17 +584,9 @@ def prep_target_ip(ip, test_suite, simulator):
         regression_name = cfg.test_suite_name + "_" + cfg.regression_name
     else:
         regression_name = cfg.regression_name
-    if simulator == "mdc":
-        gen_img_job = test_suite.get_gen_img_job()
-        gen_img_job.regression_name = regression_name
-        sim.main(gen_img_job)
-    else:
-        cmp_job  = test_suite.get_cmp_job ()
-        elab_job = test_suite.get_elab_job()
-        cmp_job .regression_name = regression_name
-        elab_job.regression_name = regression_name
-        sim.main(cmp_job )
-        sim.main(elab_job)
+    gen_img_job = test_suite.get_gen_img_job()
+    gen_img_job.regression_name = regression_name
+    sim.main(gen_img_job)
 
 
 def launch_test(ip, test_suite, sim_job, dry_mode):
